@@ -11,8 +11,6 @@ from django.dispatch import receiver
 
 from plugshop.models.product import *
 from plugshop.models.category import *
-from plugshop.models.shipping import *
-from plugshop.models.shipping_type import *
 from plugshop.models.order import *
 from plugshop.models.order_products import *
 from mptt.fields import TreeForeignKey
@@ -21,8 +19,6 @@ PRODUCT_CLASS = load_class(settings.PRODUCT_MODEL)
 CATEGORY_CLASS = load_class(settings.CATEGORY_MODEL)
 ORDER_CLASS = load_class(settings.ORDER_MODEL)
 ORDER_PRODUCTS_CLASS = load_class(settings.ORDER_PRODUCTS_MODEL)
-SHIPPING_TYPE_CLASS = load_class(settings.SHIPPING_TYPE_MODEL)
-SHIPPING_CLASS = load_class(settings.SHIPPING_MODEL)
 
 PRODUCT_CLASS.add_to_class('category', TreeForeignKey(CATEGORY_CLASS,
                                         verbose_name=_('category'),
@@ -44,17 +40,6 @@ ORDER_PRODUCTS_CLASS.add_to_class('order', models.ForeignKey(ORDER_CLASS,
 ORDER_PRODUCTS_CLASS.add_to_class('product', models.ForeignKey(PRODUCT_CLASS, 
                                         verbose_name=_('product')))
 
-SHIPPING_CLASS.add_to_class('type', models.ForeignKey(SHIPPING_TYPE_CLASS,
-                                        verbose_name=_('shipping type')))
-
-SHIPPING_CLASS.add_to_class('order', models.OneToOneField(ORDER_CLASS,
-                                        verbose_name=_('order')))
-
-@receiver(post_save, sender=SHIPPING_CLASS)
-def remove_null_shipping(sender, instance, created, **kwargs):
-    if instance.type is None:
-        instance.delete()
-
 @receiver(pre_save, sender=ORDER_CLASS)
 def set_delivered(sender, instance, **kwargs):
     if instance.status == settings.STATUS_CHOICES_FINISH:
